This data set from the United States Department of Agriculture (USDA) and its Economic Research Service department contains USA agriculture's input and output quantities along with their respective price indices for 48 States.
All quantities are expressed in thousand US$1996 and prices are relative to Alabama 1996 = 1.
usagriA data frame with 480 observations on the following 17 variables.
States48 States of the USA identified with two capital letters.
States.numState number.
YearsYear.
q.livestockLivestock and animal products' quantity, in thousand US$1996.
q.cropCrops' quantity, in thousand US$1996.
q.otherOther farm-related productions' quantity, in thousand US$1996.
q.capitalCapital services' quantity, in thousand US$1996.
q.landLand services' quantity, in thousand US$1996.
q.laborLabor services' quantity, in thousand US$1996.
q.materialsTotal intermediate input quantity, in thousand US$1996.
p.livestockLivestock and animal products' relative price (1 = Alabama 1996).
p.cropCrops' relative price (1 = Alabama 1996).
p.otherOther farm-related productions' relative price (1 = Alabama 1996).
p.capitalCapital services' relative price (1 = Alabama 1996).
p.landLand service flows' relative price (1 = Alabama 1996).
p.laborLabor services' relative price (1 = Alabama 1996).
p.materialsTotal intermediate inputs' relative price (1 = Alabama 1996).
More description on the data and the different variables can be found in the references.
Ball V.E., Gollop F.M., Kelly-Hawke A., and Swinand G.P. (1999), Patterns of state productivity growth in the US farm sector: Linking state and aggregate models. American Journal of Agricultural Economics, 81, 164--179.
Ball V.E., Hallahan C., and Nehring R. (2004), Convergence of productivity: An analysis of the catch-up hypothesis within a panel of states. American Journal of Agricultural Economics, 86(5), 1315--1321.
# NOT RUN {
head(usagri)
str(usagri)
summary(usagri)
# }
Run the code above in your browser using DataLab